==> dallinger-6.2.1.tar.gz: dallinger-6.2.1/README.md <==
Dallinger
=======
[![Build Status](https://travis-ci.org/Dallinger/Dallinger.svg?branch=master)](https://travis-ci.org/Dallinger/Dallinger)
[![Demos](https://img.shields.io/badge/demos-11-edd172.svg)](http://dallinger.readthedocs.io/en/latest/#demos)
[![codecov](https://codecov.io/gh/Dallinger/Dallinger/branch/master/graph/badge.svg)](https://codecov.io/gh/Dallinger/Dallinger)
[![Code Climate](https://codeclimate.com/github/Dallinger/Dallinger/badges/gpa.svg)](https://codeclimate.com/github/Dallinger/Dallinger)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](http://en.wikipedia.org/wiki/MIT_License)

<img src="incubator.png?raw=true" width="125" alt="Dallinger's incubator">

Laboratory automation for the behavioral and social sciences.

Features
--------
- Performs laboratory automation for the behavioral and social sciences
- Coordinates participant recruitment using Mechanical Turk

Install
-------
To install Dallinger, see [the instructions](http://dallinger.readthedocs.io/).

Documentation
-------------
Documentation is available on the [documentation website](http://dallinger.readthedocs.io/).

Demos
-----
Demonstration experiments are distributed separately in the `dlgr.demos` package.

Contribute
----------
- Issue Tracker: http://github.com/Dallinger/Dallinger/issues
- Source Code: http://github.com/Dallinger/Dallinger

Support
-------
If you are having issues, please [let us know](http://github.com/Dallinger/Dallinger/issues).
We run a users group at https://groups.google.com/d/forum/dallinger.

License
-------
The project is licensed under the MIT license.

==> dallinger-7.0.0.tar.gz: dallinger-7.0.0/README.md <==
Dallinger
=======
[![Build Status](https://github.com/dallinger/Dallinger/workflows/continuous-integration/badge.svg)](https://github.com/Dallinger/Dallinger/actions?query=workflow%3Acontinuous-integration)
[![Demos](https://img.shields.io/badge/demos-11-edd172.svg)](http://dallinger.readthedocs.io/en/latest/#demos)
[![codecov](https://codecov.io/gh/Dallinger/Dallinger/branch/master/graph/badge.svg)](https://codecov.io/gh/Dallinger/Dallinger)
[![Code Climate](https://codeclimate.com/github/Dallinger/Dallinger/badges/gpa.svg)](https://codeclimate.com/github/Dallinger/Dallinger)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](http://en.wikipedia.org/wiki/MIT_License)

<img src="incubator.png?raw=true" width="125" alt="Dallinger's incubator">

Laboratory automation for the behavioral and social sciences.

Features
--------
- Performs laboratory automation for the behavioral and social sciences
- Coordinates participant recruitment using Mechanical Turk

Install
-------
To install Dallinger, see [the instructions](http://dallinger.readthedocs.io/).

Documentation
-------------
Documentation is available on the [documentation website](http://dallinger.readthedocs.io/).

Demos
-----
Demonstration experiments are distributed separately in the `dlgr.demos` package.

Contribute
----------
- Issue Tracker: http://github.com/Dallinger/Dallinger/issues
- Source Code: http://github.com/Dallinger/Dallinger

Support
-------
If you are having issues, please [let us know](http://github.com/Dallinger/Dallinger/issues).
We run a users group at https://groups.google.com/d/forum/dallinger.

License
-------
The project is licensed under the MIT license.
